@@ -3,6 +3,7 @@
 import copy
 
 import jsonschema
+import jsonpatch
 
 
 class InvalidOperation(RuntimeError):
@@ -43,6 +44,7 @@ def model_factory(schema):
                 dict.__init__(self, d)
 
             self.__dict__['changes'] = {}
+            self.__dict__['__original__'] = copy.deepcopy(d)
 
         def __getattr__(self, key):
             try:
@@ -76,7 +78,18 @@ def model_factory(schema):
             raise InvalidOperation()
 
         def __delitem__(self, key):
-            raise InvalidOperation()
+            mutation = dict(self.items())
+            del mutation[key]
+            try:
+                self.validator(mutation)
+            except ValidationError:
+                msg = "Unable to delete attribute '%s'" % (key)
+                raise InvalidOperation(msg)
+
+            dict.__delitem__(self, key)
+
+        def __delattr__(self, key):
+            self.__delitem__(key)
 
         # NOTE(termie): This is kind of the opposite of what copy usually does
         def copy(self):
@@ -107,5 +120,10 @@ def model_factory(schema):
         def changes(self):
             return copy.deepcopy(self.__dict__['changes'])
 
+        @property
+        def patch(self):
+            original = self.__dict__['__original__']
+            return jsonpatch.make_patch(original, dict(self)).to_string()
+
     Model.__name__ = str(schema['name'])
     return Model
